@@ -42,7 +42,7 @@ class MINUETINTERFACES_EXPORT IExerciseController : public QObject
                    selectedExerciseOptionsChanged)
 
 public:
-    virtual ~IExerciseController() override = default;
+    ~IExerciseController() override = default;
 
     virtual QString errorString() const = 0;
 
@@ -58,7 +58,7 @@ Q_SIGNALS:
     void selectedExerciseOptionsChanged(QJsonArray newSelectedExerciseOptions);
 
 protected:
-    explicit IExerciseController(QObject *parent = 0);
+    explicit IExerciseController(QObject *parent = nullptr);
 
     QVariantMap m_currentExercise;
     QJsonArray m_selectedExerciseOptions;
